==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Snap/SnapDistanceManual/ts/SnapDistanceManual_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>SnapDistanceManual</name>
    <message>
        <location filename="../SnapDistanceManual.js" line="+36"/>
        <source>Specify first point to measure distance from</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Second point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SnapDistanceManualInit.js" line="+2"/>
        <source>&amp;Distance Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Snap distance between 2 points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../SnapDistanceManual.ui" line="+17"/>
        <source>Snap distance:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Distance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Percentage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Fraction</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Snap/SnapDistanceManual/ts/SnapDistanceManual_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SnapDistanceManual</name>
    <message>
        <location filename="../SnapDistanceManual.js" line="+36"/>
        <source>Specify first point to measure distance from</source>
        <translation>Proszę wskazać pierwszy punkt, od którego zostanie zmierzona odległość</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Second point</source>
        <translation>Drugi punkt</translation>
    </message>
    <message>
        <location filename="../SnapDistanceManualInit.js" line="+2"/>
        <source>&amp;Distance Manual</source>
        <translation>O&amp;dległość ręcznie</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Snap distance between 2 points</source>
        <translation>Przyciąga do odległości pomiędzy dwoma punktami</translation>
    </message>
    <message>
        <location filename="../SnapDistanceManual.ui" line="+17"/>
        <source>Snap distance:</source>
        <translation>Odległość przyciągania:</translation>
    </message>
    <message>
        <location line="+69"/>
        <source>Distance</source>
        <translation>Odległość</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Percentage</source>
        <translation>Wartość procentowa</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Fraction</source>
        <translation>Wartość ułamkowa</translation>
    </message>
</context>
</TS>
